function sdot=f_Stop_AFM_AM_25_42(t,x,...
                                N, m,...
                                CD0clean,CDflaps,CDgear,CDsp,...
                                CL0clean,CLflaps,CLalpha,...
                                Sw,h,b,k_TO,...
                                mu,muB,rho,...
                                alpha,gamma,...
                                F0,di,Tidle,BPR,...
                                vW,vREL,vEF,...
                                aSpoiler,fL, ...
                                deltaT,H,....
                    lE,lv,Sv,Sr,Av,sweepV,onlyRuder,asym0)
  
%   t => independent variable 
%   x => dependent
%        n*2 vector (y / y')

%   y'' = v' =  a
%   y'  = v
%   y   =       s


% inflow velocity v=vG+vW
% vG=S(2) ground roll speed (regarding runway) [m/s]
s  = x(1); 
vG = x(2); % vG = x'
v  = vG + vW;

... delta_CDflap. Cd_asy,... included via CD0

% mu ...
     ...concrete                    => 0.3-0.6
     ...hard turf                   => 0.4
     ...film & dry dirt             => 0.3-0.6
     ...soft turf                   => 0.5     
     ...wet & concrete              => 0.2
     ...wet grass                   => 0.2
     ...snow or ice coverd field    => 0.07-0.1

%vREL	0.12 		primary airflow of high bypass engines
...		0.25 		for straight turbojet & turboprop engines
...		0.42 		low bypass ratio engines, mixed flow
...		0.92 		fan airflow of high bypass engines

%N  % number of operating engines

g   = 9.80665; %m/s^2
W   = m*g; % weight force
AR  = b^2/Sw; % aspect ratio

% k       = 1/(pi*e*AR)
% k_TO    = 1/(1/k+pi*AR*delta_e)

alphaRad = alpha*pi/180; 
gammaRad = gamma*pi/180; 

%standard
% k1 = 2.44 * 10^(-4) * BPR  +  1.66 * 10^(-3);
% k2 = 6.16 * 10^(-7) * BPR  +  4.08 * 10^(-6);
%F1    = N*F0*( 1 - k1*v + k2*v^2); %Scholz / Young / Roskam / ...

... constants:
p0    = 101325;
R     = 287.058;
L     = 0.0065;
T0    = 288.15 + deltaT;
kappa = 1.4;

% Young 2008
p     = p0*(1-H*L/T0)^(g/(R*L)); % pressure
A     = -0.4327*(p/p0).^2+1.3855*(p/p0)+0.0472 ; %thrust factor
X     = 0.1377*(p/p0).^2-0.4374*(p/p0)+1.3003; %thrust factor
Z     = 0.9106*(p/p0).^2-1.7736*(p/p0)+1.8697; %thrust factor
T     = T0-0.0065*H; %temperature as a funcion of height
c     = sqrt(R*kappa*T); %speed of sound

... linear G-factor function: 
G     = 0.061*BPR + 0.633; % gas generator factor, Young 2008
... => A340, BPR = 7.6
... => A320, BPR = 6
... equation determined in excel with 2 values of the original diagram 
    
... thrust factors:
K1   =  (((0.377*(1+BPR))  /   sqrt((1+0.82*BPR)*G)))*Z * (p/p0);
K2   =  (0.23+0.19*sqrt(BPR)).*X.*p/p0 ;

...R    = 0; % reverse thrust, not allowed for BFL with dry runway

AN   =     pi/4*di^2; % area => inlet, engine
% M       = v/c; % mach number
% CDwm    = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; %windmill drag:
phi     = (16*h/b)^2 / (1+(16*h/b)^2); %ground effect
qv = rho*0.5*v^2; % dynamic pressure
...______________________________________________________________________________________________________
if t    >= 0 && t < 1 % engine failure 
    ...                 => 1 sec until recognition
    ...                 => v = vEF
    ...                 => windmilldrad considered
    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; 
              dF    = (1*F0*( A - K1*(v/c) + K2*(v/c).^2)) + CDwm;
    if onlyRuder ==true
              Cyv = dF / (Sv*qv) *lE/lv;
              CDs = 2.3/pi *sqrt(Sr*Sv)*Av^(-4/3) *cos(sweepV*pi/180)^(1/3)*Cyv^2;
              CDasym = CDs / Sw; % rudder onöy
    elseif asym0 == true
              CDasym = 0;
    end

    CLg  = (CL0clean + CLflaps) + CLalpha*alphaRad ;  
    CD0  = CD0clean + CDflaps + CDgear + CDwm + CDasym +CDsp;
    CD   = CD0 + phi*k_TO*CLg^2;  
    F    = (N-1)*F0*( A - K1*(M)  +    K2*(M).^2) ;
    a    = -g*mu *((fL*cos(gammaRad)+sin(gammaRad)/mu -F/(W*mu)) +rho/2*Sw/W*(CD/mu -CLg )*v^2);     
...______________________________________________________________________________________________________
elseif t >= 1 && t < 3 % AFM Buffer, v=vEF
%     vG = vEF;
%     a    = 0;

    ...                 => 1 sec until recognition
    ...                 => v = vEF
    ...                 => windmilldrad considered
    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; 
              dF    = (1*F0*( A - K1*(v/c) + K2*(v/c).^2)) + CDwm;
    if onlyRuder ==true
              Cyv = dF / (Sv*qv) *lE/lv;
              CDs = 2.3/pi *sqrt(Sr*Sv)*Av^(-4/3) *cos(sweepV*pi/180)^(1/3)*Cyv^2;
              CDasym = CDs / Sw; % rudder onöy
    elseif asym0 == true
              CDasym = 0;
    end

    CLg  = (CL0clean + CLflaps) + CLalpha*alphaRad ;  
    CD0  = CD0clean + CDflaps + CDgear + CDwm + CDasym +CDsp;
    CD   = CD0 + phi*k_TO*CLg^2;  
    F    = (N-1)*F0*( A - K1*(M)  +    K2*(M).^2) ;
    a    = -g*mu *((fL*cos(gammaRad)+sin(gammaRad)/mu -F/(W*mu)) +rho/2*Sw/W*(CD/mu -CLg )*v^2);    

...______________________________________________________________________________________________________    
elseif t >= 3 && t < 3.5 % 1st reaction => brakes => mu = muB 
    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; 
              dF    = (1*F0*( A - K1*(v/c) + K2*(v/c).^2)) + CDwm;
    if onlyRuder ==true
              Cyv = dF / (Sv*qv) *lE/lv;
              CDs = 2.3/pi *sqrt(Sr*Sv)*Av^(-4/3) *cos(sweepV*pi/180)^(1/3)*Cyv^2;
              CDasym = CDs / Sw; % rudder onöy
    elseif asym0 == true
              CDasym = 0;
    end

    CLg  = (CL0clean + CLflaps) + CLalpha*alphaRad ;  
    CD0  = CD0clean + CDflaps + CDgear + CDwm + CDasym +CDsp;
    CD   = CD0 + phi*k_TO*CLg^2;
     F    = (N-1)*F0*( A - K1*(M)  +    K2*(M).^2) ;        
        if t >= 3 && t < 3.1
        muBx = 0.1* muB;
        elseif t >= 3.1 && t < 3.2
        muBx = 0.2* muB;
        elseif t >= 3.2 && t < 3.3
        muBx = 0.3* muB;
        elseif t >= 3.3 && t < 3.4
        muBx = 0.4* muB;
        elseif t >= 3.4 && t < 3.5
        muBx = 0.5* muB;
        end
    a    = -g*muBx *((fL*cos(gammaRad)+sin(gammaRad)/muBx -F/(W*muBx)) +rho/2*Sw/W*(CD/muBx -CLg )*v^2);
...______________________________________________________________________________________________________
elseif t >= 3.5 && t < 4   % 2nd reaction => Fo = idle thrust
    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; 
    CLg  = (CL0clean + CLflaps) + CLalpha*alphaRad ;
    CD0  =(CD0clean + CDflaps) + CDgear + CDwm+ 0 +CDsp; %idle thrust, yaw momnt neglected 
    CD   = CD0 + phi*k_TO*CLg^2;
    F    = (N-1)*Tidle*( A - K1*(M)  +    K2*(M).^2) ;
        if t >= 3.5 && t < 3.6
        muBx = 0.6* muB;
        elseif t >= 3.6 && t < 3.7
        muBx = 0.7* muB;
        elseif t >= 3.7 && t < 3.8
        muBx = 0.8* muB;
        elseif t >= 3.8 && t < 3.9
        muBx = 0.9* muB;
        elseif t >= 3.9 && t < 4
        muBx = 1* muB;           
        end
    a    = -g*muBx *((fL*cos(gammaRad)+sin(gammaRad)/muBx -F/(W*muBx)) +rho/2*Sw/W*(CD/muBx -CLg )*v^2); 
...______________________________________________________________________________________________________
elseif t >= 4  % 3rd reaction => spoiler / flaps
    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw;
    CLg  = (CL0clean + CLflaps) + CLalpha*alphaRad ;
    CD0  = (CD0clean + CDflaps) + CDgear + CDwm + 0 +CDsp; %idle thrust, yaw momnt neglected 
    CD   = CD0 + phi*k_TO*CLg^2;
    F    = (N-1)*Tidle*( A - K1*(M)  +    K2*(M).^2) ;
    ...spoiler via parameter aSpoiler:
    a    = -g*muB *((fL*cos(gammaRad)+sin(gammaRad)/muB + aSpoiler/(g*muB) -F/(W*muB)) +rho/2*Sw/W*(CD/muB -CLg )*v^2);
end
...______________________________________________________________________________________________________
sdot(1,1) = vG;  % v = s' =  ds/dt
sdot(2,1) = a; % v' = s'' = a

return